package DBIx::Class::Schema::AuditLog::Structure::Base;
{
  $DBIx::Class::Schema::AuditLog::Structure::Base::VERSION = '0.4.0';
}

use base 'DBIx::Class::Core';

1;

__END__

=pod

=head1 NAME

DBIx::Class::Schema::AuditLog::Structure::Base

=head1 VERSION

version 0.4.0

=head1 AUTHOR

Mark Jubenville <ioncache@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2012 by Mark Jubenville.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
